@@ -38,6 +38,20 @@ AnyIPAddressFamily = Literal[AddressFamily.AF_UNSPEC, AddressFamily.AF_INET,
 
 pytestmark = pytest.mark.anyio
 
+# If a socket can bind to ::1, the current environment has IPv6 properly configured
+has_ipv6 = False
+if socket.has_ipv6:
+    s = socket.socket(AddressFamily.AF_INET6)
+    try:
+        s.bind(('::1', 0))
+    except OSError:
+        pass
+    else:
+        has_ipv6 = True
+    finally:
+        s.close()
+        del s
+
 
 @pytest.fixture
 def fake_localhost_dns(monkeypatch: MonkeyPatch) -> None:
@@ -53,7 +67,7 @@ def fake_localhost_dns(monkeypatch: MonkeyPatch) -> None:
 @pytest.fixture(params=[
     pytest.param(AddressFamily.AF_INET, id='ipv4'),
     pytest.param(AddressFamily.AF_INET6, id='ipv6',
-                 marks=[pytest.mark.skipif(not socket.has_ipv6, reason='no IPv6 support')])
+                 marks=[pytest.mark.skipif(not has_ipv6, reason='no IPv6 support')])
 ])
 def family(request: SubRequest) -> AnyIPAddressFamily:
     return request.param
@@ -194,7 +208,7 @@ class TestTCPStream:
             raw_socket = stream.extra(SocketAttribute.raw_socket)
             assert raw_socket.getsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY) != 0
 
-    @pytest.mark.skipif(not socket.has_ipv6, reason='IPv6 is not available')
+    @pytest.mark.skipif(not has_ipv6, reason='IPv6 is not available')
     @pytest.mark.parametrize('local_addr, expected_client_addr', [
         pytest.param('', '::1', id='dualstack'),
         pytest.param('127.0.0.1', '127.0.0.1', id='ipv4'),
@@ -227,7 +241,7 @@ class TestTCPStream:
     @pytest.mark.parametrize('target, exception_class', [
         pytest.param(
             'localhost', ExceptionGroup, id='multi',
-            marks=[pytest.mark.skipif(not socket.has_ipv6, reason='IPv6 is not available')]
+            marks=[pytest.mark.skipif(not has_ipv6, reason='IPv6 is not available')]
         ),
         pytest.param('127.0.0.1', ConnectionRefusedError, id='single')
     ])
@@ -441,9 +455,9 @@ class TestTCPListener:
     @pytest.mark.parametrize('family', [
         pytest.param(AddressFamily.AF_INET, id='ipv4'),
         pytest.param(AddressFamily.AF_INET6, id='ipv6',
-                     marks=[pytest.mark.skipif(not socket.has_ipv6, reason='no IPv6 support')]),
+                     marks=[pytest.mark.skipif(not has_ipv6, reason='no IPv6 support')]),
         pytest.param(socket.AF_UNSPEC, id='both',
-                     marks=[pytest.mark.skipif(not socket.has_ipv6, reason='no IPv6 support')])
+                     marks=[pytest.mark.skipif(not has_ipv6, reason='no IPv6 support')])
     ])
     async def test_accept(self, family: AnyIPAddressFamily) -> None:
         async with await create_tcp_listener(local_host='localhost', family=family) as multi:
